@@ -21,8 +21,8 @@ import gc
 from pathlib import Path
 import shutil
 
-import tensorflow.keras.layers as L
-from tensorflow.keras import Model
+# import tensorflow.keras.layers as L
+# from tensorflow.keras import Model
 
 from ._encoders import *
 from ._logger import *
@@ -37,169 +37,169 @@ np.random.seed(RANDOM_SEED)
 random.seed(RANDOM_SEED)
 
 
-class DenoisingAutoencoder(object):
-    """
-    Denoising autoencoders (DAE) for numerical features. try to achieve a good representation by changing the reconstruction criterion
-    https://en.wikipedia.org/wiki/Autoencoder#Denoising_autoencoder_(DAE)
+# class DenoisingAutoencoder(object):
+#     """
+#     Denoising autoencoders (DAE) for numerical features. try to achieve a good representation by changing the reconstruction criterion
+#     https://en.wikipedia.org/wiki/Autoencoder#Denoising_autoencoder_(DAE)
 
-    Examples
-    --------
-    >>> from automl_alex import DenoisingAutoencoder, CleanNans
-    >>> import sklearn
-    >>> # Get Dataset
-    >>> dataset = sklearn.datasets.fetch_openml(name='adult', version=1, as_frame=True)
-    >>> dataset.target = dataset.target.astype('category').cat.codes
-    >>> X_train, X_test, y_train, y_test = sklearn.model_selection.train_test_split(
-    >>>                                             dataset.data,
-    >>>                                             dataset.target,
-    >>>                                             test_size=0.2,)
-    >>>
-    >>> # clean nans before use
-    >>> cn = CleanNans()
-    >>> clean_X_train = cn.fit_transform(X_train)
-    >>> clean_X_test = cn.transform(X_test)
-    >>>
-    >>> # get Numeric Features
-    >>> num_columns = list(clean_X_train.select_dtypes('number').columns)
-    >>>
-    >>> nf = DenoisingAutoencoder()
-    >>> new_features_X_train = nf.fit_transform(clean_X_train, num_columns)
-    >>> new_features_X_test = nf.transform(clean_X_test)
-    """
+#     Examples
+#     --------
+#     >>> from automl_alex import DenoisingAutoencoder, CleanNans
+#     >>> import sklearn
+#     >>> # Get Dataset
+#     >>> dataset = sklearn.datasets.fetch_openml(name='adult', version=1, as_frame=True)
+#     >>> dataset.target = dataset.target.astype('category').cat.codes
+#     >>> X_train, X_test, y_train, y_test = sklearn.model_selection.train_test_split(
+#     >>>                                             dataset.data,
+#     >>>                                             dataset.target,
+#     >>>                                             test_size=0.2,)
+#     >>>
+#     >>> # clean nans before use
+#     >>> cn = CleanNans()
+#     >>> clean_X_train = cn.fit_transform(X_train)
+#     >>> clean_X_test = cn.transform(X_test)
+#     >>>
+#     >>> # get Numeric Features
+#     >>> num_columns = list(clean_X_train.select_dtypes('number').columns)
+#     >>>
+#     >>> nf = DenoisingAutoencoder()
+#     >>> new_features_X_train = nf.fit_transform(clean_X_train, num_columns)
+#     >>> new_features_X_test = nf.transform(clean_X_test)
+#     """
 
-    autoencoder = None
+#     autoencoder = None
 
-    def __init__(self, verbose: int = 0) -> None:
-        """
-        Parameters
-        ----------
-        verbose : int,
-            print state, by default 0
-        """
-        self.verbose = verbose
+#     def __init__(self, verbose: int = 0) -> None:
+#         """
+#         Parameters
+#         ----------
+#         verbose : int,
+#             print state, by default 0
+#         """
+#         self.verbose = verbose
 
-    def _get_dae(
-        self,
-        caunt_columns: int,
-        units: Optional[int] = 512,
-    ):
-        # denoising autoencoder
-        inputs = L.Input((caunt_columns,))
-        x = L.Dense(units, activation="relu")(inputs)  # 1500 original
-        x = L.Dense(units, activation="relu")(x)  # 1500 original
-        x = L.Dense(units, activation="relu")(x)  # 1500 original
-        outputs = L.Dense(caunt_columns, activation="relu")(x)
-        model = Model(inputs=inputs, outputs=outputs)
-        model.compile(optimizer="adam", loss="mse")
-        return model
+#     def _get_dae(
+#         self,
+#         caunt_columns: int,
+#         units: Optional[int] = 512,
+#     ):
+#         # denoising autoencoder
+#         inputs = L.Input((caunt_columns,))
+#         x = L.Dense(units, activation="relu")(inputs)  # 1500 original
+#         x = L.Dense(units, activation="relu")(x)  # 1500 original
+#         x = L.Dense(units, activation="relu")(x)  # 1500 original
+#         outputs = L.Dense(caunt_columns, activation="relu")(x)
+#         model = Model(inputs=inputs, outputs=outputs)
+#         model.compile(optimizer="adam", loss="mse")
+#         return model
 
-    @logger.catch
-    def fit(self, data: pd.DataFrame, cols: Optional[List[str]] = None) -> None:
-        """
-        Parameters
-        ----------
-        data : pd.DataFrame
-            dataset (pd.DataFrame shape = (n_samples, n_features))
-        cols : Optional[List[str]], optional
-            cols list features, by default None
+#     @logger.catch
+#     def fit(self, data: pd.DataFrame, cols: Optional[List[str]] = None) -> None:
+#         """
+#         Parameters
+#         ----------
+#         data : pd.DataFrame
+#             dataset (pd.DataFrame shape = (n_samples, n_features))
+#         cols : Optional[List[str]], optional
+#             cols list features, by default None
 
-        Returns
-        -------
-        self
+#         Returns
+#         -------
+#         self
 
-        Raises
-        ------
-        Exception
-            No numerical features
-        """
-        if cols is not None:
-            data = data[cols]
+#         Raises
+#         ------
+#         Exception
+#             No numerical features
+#         """
+#         if cols is not None:
+#             data = data[cols]
 
-        data = data._get_numeric_data()
-        self.columns = data.columns
-        count_columns = len(self.columns)
+#         data = data._get_numeric_data()
+#         self.columns = data.columns
+#         count_columns = len(self.columns)
 
-        if count_columns < 1:
-            raise ValueError("No numerical features")
+#         if count_columns < 1:
+#             raise ValueError("No numerical features")
 
-        self.scaler = MinMaxScaler().fit(data)
-        s_data = self.scaler.transform(data)
+#         self.scaler = MinMaxScaler().fit(data)
+#         s_data = self.scaler.transform(data)
 
-        units = 512
-        if count_columns > 512:
-            units = count_columns
+#         units = 512
+#         if count_columns > 512:
+#             units = count_columns
 
-        self.autoencoder = self._get_dae(count_columns, units=units)
-        self.autoencoder.fit(
-            s_data,
-            s_data,
-            epochs=50,
-            batch_size=124,
-            shuffle=True,
-            verbose=self.verbose,
-        )
-        return self
+#         self.autoencoder = self._get_dae(count_columns, units=units)
+#         self.autoencoder.fit(
+#             s_data,
+#             s_data,
+#             epochs=50,
+#             batch_size=124,
+#             shuffle=True,
+#             verbose=self.verbose,
+#         )
+#         return self
 
-    @logger.catch
-    def transform(
-        self, data: pd.DataFrame, cols: Optional[List[str]] = None
-    ) -> pd.DataFrame:
-        """
-        Transforms the dataset.
+#     @logger.catch
+#     def transform(
+#         self, data: pd.DataFrame, cols: Optional[List[str]] = None
+#     ) -> pd.DataFrame:
+#         """
+#         Transforms the dataset.
 
-        Parameters
-        ----------
-        data : pd.DataFrame
-            dataset (pd.DataFrame shape = (n_samples, n_features))
-        cols : Optional[List[str]], optional
-            cols list features, by default None
+#         Parameters
+#         ----------
+#         data : pd.DataFrame
+#             dataset (pd.DataFrame shape = (n_samples, n_features))
+#         cols : Optional[List[str]], optional
+#             cols list features, by default None
 
-        Returns
-        -------
-        pd.DataFrame
-            The dataset with Transform data
+#         Returns
+#         -------
+#         pd.DataFrame
+#             The dataset with Transform data
 
-        Raises
-        ------
-        Exception
-            if No fit autoencoder
-        """
-        if self.autoencoder is None:
-            raise Exception("No fit autoencoder")
+#         Raises
+#         ------
+#         Exception
+#             if No fit autoencoder
+#         """
+#         if self.autoencoder is None:
+#             raise Exception("No fit autoencoder")
 
-        if cols is not None:
-            data = data[cols]
+#         if cols is not None:
+#             data = data[cols]
 
-        s_data = self.scaler.transform(data[self.columns])
-        encodet_data = self.autoencoder.predict(s_data)
-        encodet_data = pd.DataFrame(encodet_data, columns=self.columns)
-        return encodet_data
+#         s_data = self.scaler.transform(data[self.columns])
+#         encodet_data = self.autoencoder.predict(s_data)
+#         encodet_data = pd.DataFrame(encodet_data, columns=self.columns)
+#         return encodet_data
 
-    def fit_transform(
-        self, data: pd.DataFrame, cols: Optional[List[str]] = None
-    ) -> pd.DataFrame:
-        """
-        Fit and Transforms the dataset.
+#     def fit_transform(
+#         self, data: pd.DataFrame, cols: Optional[List[str]] = None
+#     ) -> pd.DataFrame:
+#         """
+#         Fit and Transforms the dataset.
 
-        Parameters
-        ----------
-        data : pd.DataFrame
-            dataset (pd.DataFrame shape = (n_samples, n_features))
-        cols : Optional[List[str]], optional
-            cols list features, by default None
+#         Parameters
+#         ----------
+#         data : pd.DataFrame
+#             dataset (pd.DataFrame shape = (n_samples, n_features))
+#         cols : Optional[List[str]], optional
+#             cols list features, by default None
 
-        Returns
-        -------
-        pd.DataFrame
-            The dataset with Transform data
+#         Returns
+#         -------
+#         pd.DataFrame
+#             The dataset with Transform data
 
-        Raises
-        ------
-        Exception
-            No numerical features
-        """
-        self.fit(data, cols)
-        return self.transform(data)
+#         Raises
+#         ------
+#         Exception
+#             No numerical features
+#         """
+#         self.fit(data, cols)
+#         return self.transform(data)
 
 
 class CleanNans(object):
@@ -783,7 +783,7 @@ class DataPrepare(object):
             "*",
             "-",
         ],
-        num_denoising_autoencoder: bool = False,
+        # num_denoising_autoencoder: bool = False,
         # group_generator_features=False,
         # frequency_enc_num_features=False,
         normalization: bool = False,
@@ -812,8 +812,6 @@ class DataPrepare(object):
             generate num features, by default True
         num_generator_operations : List[str], optional
             operations for generate num features, by default ['/','*','-',]
-        num_denoising_autoencoder : bool, optional
-            generate num denoising autoencoder features, by default False
         normalization : bool, optional
             On or Off, by default True
         reduce_memory : bool, optional
@@ -836,7 +834,7 @@ class DataPrepare(object):
         self._drop_invariant = drop_invariant
         self._outliers_method = outliers_method
         self._num_generator_features = num_generator_features
-        self._num_denoising_autoencoder = num_denoising_autoencoder
+        #self._num_denoising_autoencoder = num_denoising_autoencoder
         self._num_generator_operations = num_generator_operations
         self._normalization = normalization
         self._reduce_memory = reduce_memory
@@ -1024,17 +1022,17 @@ class DataPrepare(object):
                 logger.info("  No nans features")
 
         # DenoisingAutoencoder
-        if self._num_denoising_autoencoder:
-            if len(self.num_features) > 2:
-                logger.info("> Start fit DenoisingAutoencoder")
-                self._autoencoder = DenoisingAutoencoder(verbose=self.verbose)
-                data_encodet = self._autoencoder.fit_transform(data[self.num_features])
-                data_encodet = data_encodet.add_prefix("DenoisingAutoencoder_")
-                data = pd.concat(
-                    [data.reset_index(drop=True), data_encodet.reset_index(drop=True)],
-                    axis=1,
-                )
-                logger.info("> Add Denoising features")
+        # if self._num_denoising_autoencoder:
+        #     if len(self.num_features) > 2:
+        #         logger.info("> Start fit DenoisingAutoencoder")
+        #         self._autoencoder = DenoisingAutoencoder(verbose=self.verbose)
+        #         data_encodet = self._autoencoder.fit_transform(data[self.num_features])
+        #         data_encodet = data_encodet.add_prefix("DenoisingAutoencoder_")
+        #         data = pd.concat(
+        #             [data.reset_index(drop=True), data_encodet.reset_index(drop=True)],
+        #             axis=1,
+        #         )
+        #         logger.info("> Add Denoising features")
 
         # CleanOutliers
         if self._clean_outliers:
@@ -1190,15 +1188,15 @@ class DataPrepare(object):
             logger.info("> Clean Nans")
 
         # DenoisingAutoencoder
-        if self._num_denoising_autoencoder:
-            if len(self.num_features) > 2:
-                data_encodet = self._autoencoder.transform(data[self.num_features])
-                data_encodet = data_encodet.add_prefix("DenoisingAutoencoder_")
-                data = pd.concat(
-                    [data.reset_index(drop=True), data_encodet.reset_index(drop=True)],
-                    axis=1,
-                )
-                logger.info("> Add Denoising features")
+        # if self._num_denoising_autoencoder:
+        #     if len(self.num_features) > 2:
+        #         data_encodet = self._autoencoder.transform(data[self.num_features])
+        #         data_encodet = data_encodet.add_prefix("DenoisingAutoencoder_")
+        #         data = pd.concat(
+        #             [data.reset_index(drop=True), data_encodet.reset_index(drop=True)],
+        #             axis=1,
+        #         )
+        #         logger.info("> Add Denoising features")
 
         # CleanOutliers
         if self._clean_outliers:
